PlaybackInfo class

Video playback information.

Constructors

PlaybackInfo({required PlaybackStatus status, required int position, required double positionFraction, required double volume, required double speed, String? error})
NOTE: for internal use only.

Properties

error → String?
An error message, if playback failed.
final
hashCode → int
The hash code for this object.
no setterinherited
position → int
The current playback position, in seconds.
final
positionFraction → double
The current playback position as a value between 0 and 1.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speed → double
The current playback speed.
final
status → PlaybackStatus
The current playback status.
final
volume → double
The current playback volume.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited