VideoInfo class

Class that contains the attributes of a video file.

Annotations
  • @JsonSerializable.new()

Constructors

VideoInfo({required int height, required int width, required int duration})
NOTE: For internal use only.
VideoInfo.fromJson(Map<String, dynamic> json)
factory

Properties

aspectRatio → double
Aspect ratio of the video frame, in pixels.
no setter
duration → int
Duration of the video, in seconds.
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
Height of the video frame, in pixels.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
Width of the video frame, in pixels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited